import React, { Component } from 'react';
import { Row, Col } from 'antd';

import Dropzone from '@imd/components/uielements/dropzone';
import { notification } from '@imd/components';
import PageHeader from '@imd/components/utility/pageHeader';
import Box from '@imd/components/utility/box';
import LayoutWrapper from '@imd/components/utility/layoutWrapper';
import ContentHolder from '@imd/components/utility/contentHolder';
import DropzoneWrapper from './Import.styles';

import basicStyle from '@imd/assets/styles/constants';
import FrappeChart from 'frappe-charts/dist/frappe-charts.min.esm';
import * as configs from './config';
import 'frappe-charts/dist/frappe-charts.min.css';
import IsoWidgetsWrapper from '@imd/containers/Widgets/WidgetsWrapper';

import CardWidget from '@imd/containers/Widgets/Card/CardWidget';
import IntlMessages from '@imd/components/utility/intlMessages';

export default class extends Component {

  componentDidMount() {
    new FrappeChart(configs.impressionsLineChart);
  }

  render() {

    const CARD_WIDGET = [
    {
      icon: 'ion-ios-people',
      iconcolor: '#42A5F5',
      number: '210',
      text: 'widget.tinder.matches.text',
    },
    {
      icon: 'ion-chatbox',
      iconcolor: '#F75D81',
      number: '540',
      text: 'widget.tinder.messages.text',
    },
    {
      icon: 'ion-trophy',
      iconcolor: '#FEAC01',
      number: 'widget.cardwidget3.number',
      text: 'widget.cardwidget3.text',
    },
  ];

    //##########
    //Dropzone
    //##########
    const componentConfig = {
      iconFiletypes: ['.json'],
      method: true,
      showFiletypeIcon: false,
      uploadMultiple: false,
      maxFilesize: 2, // MB
      maxFiles: 1,
      dictRemoveFile: 'Delete',
      dictCancelUploadConfirmation: 'Are you sure to cancel upload?',
      postUrl: '/upload',
    };
    const djsConfig = {
      acceptedFiles: '.json',
      params: {
        account: "tinder"
      }
    };
    const eventHandlers = {
      addedfile: file => notification('success', `${file.name} added`),
      success: file =>
        notification('success', `${file.name} successfully uploaded`),
      error: error => notification('error', 'Server is not set in the demo')
    };

    const { rowStyle, colStyle, gutter } = basicStyle;

    return (
      <LayoutWrapper>
        <PageHeader>Import</PageHeader>
        <Row style={rowStyle} gutter={gutter} justify="start">
            <Col span={24} style={colStyle}>
            <Box>
              <u>How To Download Your Spotify Data:</u> <br></br>
              1. Log in to <a href="https://www.spotify.com/us/">spotify.com</a> <br></br>
              2. Click <b>Log In</b> and enter your credentials <br></br>
              3. Select <b>Privacy Settings</b> from the left-hand navigation<br></br>
              4. Scroll down to <b>Download Your Data</b> and select <b>Request</b><br></br>
              5. Go to your email to confirm your request<br></br>
              6. Upload your data in the dropbox below<br></br>
            </Box>
            </Col>
        </Row>
        <Box>
          <ContentHolder>
            <DropzoneWrapper>
              <Dropzone
                config={componentConfig}
                eventHandlers={eventHandlers}
                djsConfig={djsConfig}
              />
            </DropzoneWrapper>
          </ContentHolder>
        </Box>
      </LayoutWrapper>
    );
  };
}
